%define pre_rel		beta19
%define build_slang	1
%define build_java	0
%define build_doc	0

%define major		0
%define libname		%mklibname caca %{major}
%define develname	%mklibname caca -d

%define build_mono	0
%ifarch %mips %arm aarch64
%define build_mono	0
%endif

Name:		libcaca
Version:	0.99
%define 	subrel 1
Release:	%mkrel -c %{pre_rel} 5
Summary:	Text mode graphics library
License:	WTFPL
Group:		System/Libraries
URL:		http://libcaca.zoy.org/
Source0:	http://caca.zoy.org/files/libcaca/%{name}-%{version}%{?pre_rel:.%{pre_rel}}.tar.gz
Patch0:		libcaca-ruby2.2.patch
#
# Security patches
# P100 -> ...
#
Patch100:		CVE-2018-20544.patch
Patch101:		CVE-2018-20545_20458_20549.patch
Patch102:		CVE-2018-20546_20547.patch
# CVE-2021-3410: https://github.com/cacalabs/libcaca/issues/52
Patch103:		CVE-2021-3410-1.patch
Patch104:		CVE-2021-3410-2.patch
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(ncursesw) >= 5
%if %build_slang
BuildRequires:	pkgconfig(slang)
%endif
BuildRequires:	pkgconfig(imlib2)
BuildRequires:	pkgconfig(freeglut)
BuildRequires:	pkgconfig(ftgl)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(zlib)
%if %{build_doc}
BuildRequires:	doxygen
BuildRequires:	tetex-latex
BuildRequires:	tetex-dvips
%endif
BuildRequires:	pkgconfig(ruby)
%if %{build_mono}
BuildRequires:	mono
%endif


%description
libcaca is the Colour AsCii Art library. It provides high level functions
for colour text drawing, simple primitives for line, polygon and ellipse
drawing, as well as powerful image to text conversion routines.

%package -n	%{libname}
Summary:	Text mode graphics library
Group:		System/Libraries

%description -n	%{libname}
libcaca is the Colour AsCii Art library. It provides high level functions
for colour text drawing, simple primitives for line, polygon and ellipse
drawing, as well as powerful image to text conversion routines.


%package -n	%{develname}
Summary:	Development files for libcaca
Group:		Development/C
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{libname} = %{version}

%description -n	%{develname}
libcaca is the Colour AsCii Art library. It provides high level functions
for colour text drawing, simple primitives for line, polygon and ellipse
drawing, as well as powerful image to text conversion routines.

This package contains the header files and static libraries needed to
compile applications or shared objects that use libcaca.

%package -n	caca-utils
Summary:	Text mode graphics utilities
Group:		Graphics/Utilities

%description -n	caca-utils
This package contains utilities and demonstration programs for libcaca, the
Colour AsCii Art library.

cacaview is a simple image viewer for the terminal. It opens most image
formats such as JPEG, PNG, GIF etc. and renders them on the terminal using
ASCII art. The user can zoom and scroll the image, set the dithering method
or enable anti-aliasing.

cacaball is a tiny graphic program that renders animated ASCII metaballs on
the screen, cacafire is a port of AALib's aafire and displays burning ASCII
art flames, cacamoir animates colourful moire circles and cacaplas displays
an old school plasma effect.

cacademo is a simple application that shows the libcaca rendering features
such as line and ellipses drawing, triangle filling and sprite blitting.

%if %{build_mono}
%package -n	caca-sharp
Summary:	C# binding for libcaca
Group:		Development/C#

%description -n	caca-sharp
C# binding for libcaca.
%endif

%package -n	ruby-caca
Summary:	Ruby binding for libcaca
Group:		Development/Ruby

%description -n	ruby-caca
Ruby binding for libcaca.

%package -n	python3-caca
Summary:	Python 3 binding for libcaca
Group:		Development/Python
%{?python_provide:%python_provide python3-caca}

%description -n	python3-caca
Python 3 binding for libcaca.

%prep
%setup -q -n %{name}-%{version}.%{pre_rel}
%autopatch -p1
sed -i s/AM_CONFIG_HEADER/AC_CONFIG_HEADER/ configure.ac

for file in python/examples/*.py; do
   sed -e 's|/usr/bin/env python$|%{__python3}|g' ${file} > ${file}.tmp
   touch -r ${file} ${file}.tmp
   mv -f ${file}.tmp ${file}
done

%build
autoreconf -fi
%configure \
%if %build_slang
	--enable-slang \
%else
	--disable-slang \
%endif
%if ! %build_java
	--disable-java \
%endif
	--enable-ncurses \
	--enable-x11 \
	--enable-imlib2 \
%if ! %{build_doc}
	--disable-doc \
%endif
	--enable-plugins \
	--disable-static

%make_build

%install
rm -rf %{buildroot} installed-docs
%make_install

rm -f %{buildroot}%{ruby_vendorarchdir}/*.la

%multiarch_binaries %{buildroot}%{_bindir}/caca-config

%if %{build_doc}
mv %{buildroot}%{_datadir}/doc/libcaca-dev installed-docs
mkdir %{buildroot}%{_datadir}/doc/caca-utils-%{version}
rm %{buildroot}%{_datadir}/doc/libcucul-dev
%endif

#we don't want these
find %{buildroot} -name "*.la" -delete

%files -n %{libname}
%{_libdir}/lib*.so.%{major}{,.*}
%dir %{_libdir}/caca

# FIXME split them into subpackage, to avoid dependency on X
%{_libdir}/caca/lib*.so.%{major}{,.*}

%files -n %{develname}
%if %{build_doc}
%doc installed-docs/html
%endif
%doc NEWS NOTES
%{_bindir}/caca-config
%{multiarch_bindir}/caca-config
%{_includedir}/*
%{_mandir}/man1/caca-config.1*
%if %{build_doc}
%{_mandir}/man3/*
%endif
%{_libdir}/pkgconfig/*.pc
%{_libdir}/lib*.so
%{_libdir}/caca/lib*.so

%files -n caca-utils
%doc README THANKS AUTHORS
%{_bindir}/cacaclock
%{_bindir}/cacademo
%{_bindir}/cacafire
%{_bindir}/cacaplay
%{_bindir}/cacaserver
%{_bindir}/cacaview
%{_bindir}/img2txt
%{_datadir}/libcaca/
%{_mandir}/man1/cacademo.1*
%{_mandir}/man1/cacafire.1*
%{_mandir}/man1/cacaplay.1*
%{_mandir}/man1/cacaserver.1*
%{_mandir}/man1/cacaview.1*
%{_mandir}/man1/img2txt.1*

%files -n python3-caca
%{python3_sitelib}/caca/

%if %{build_mono}
%files -n caca-sharp
%{_libdir}/mono/caca-sharp*
%{_libdir}/mono/gac/caca-sharp
%endif

%files -n ruby-caca
%{ruby_vendorlibdir}/caca.rb
%{ruby_vendorarchdir}/*.so


%changelog
* Mon Mar 08 2021 neoclust <neoclust> 0.99-0.beta19.5.1.mga8
+ Revision: 1700755
- Add P103/104: Fixes CVE-2021-3410 (mga#28556)

* Mon Mar 02 2020 pterjan <pterjan> 0.99-0.beta19.5.mga8
+ Revision: 1553143
- Rebuild for ruby 2.7

* Sat Feb 15 2020 daviddavid <daviddavid> 0.99-0.beta19.4.mga8
+ Revision: 1526510
- port to python3
- drop python2 support
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Jan 21 2019 luigiwalser <luigiwalser> 0.99-0.beta19.3.mga7
+ Revision: 1358563
- remove unused patch
- add patches from ubuntu to fix CVE-2018-2054[4-9]

* Sun Sep 23 2018 umeabot <umeabot> 0.99-0.beta19.2.mga7
+ Revision: 1298773
- Mageia 7 Mass Rebuild

* Wed Apr 04 2018 kekepower <kekepower> 0.99-0.beta19.1.mga7
+ Revision: 1215266
- Update to version 0.99.beta19
- Rediffed ruby patch
+ wally <wally>
- disable doc build for now

* Mon Jan 01 2018 pterjan <pterjan> 0.99-0.beta18.16.mga7
+ Revision: 1188459
- Rebuild for Ruby 2.5

* Sun Sep 03 2017 pterjan <pterjan> 0.99-0.beta18.15.mga7
+ Revision: 1150977
- Install ruby module into vendor dir
- Rebuild for new Ruby

* Fri Feb 12 2016 luigiwalser <luigiwalser> 0.99-0.beta18.13.mga6
+ Revision: 959337
- disable mono build for now

* Sat Nov 07 2015 pterjan <pterjan> 0.99-0.beta18.12.mga6
+ Revision: 898365
- Fix a bit more ruby 2.2 patch
- Update ruby patch for ruby 2.2

* Mon Oct 19 2015 daviddavid <daviddavid> 0.99-0.beta18.11.mga6
+ Revision: 892775
- fix python macros (fix build failure)

* Wed Oct 15 2014 umeabot <umeabot> 0.99-0.beta18.10.mga5
+ Revision: 745186
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.99-0.beta18.9.mga5
+ Revision: 726696
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 0.99-0.beta18.8.mga5
+ Revision: 681357
- Mageia 5 Mass Rebuild

* Sat May 31 2014 pterjan <pterjan> 0.99-0.beta18.7.mga5
+ Revision: 628290
- Rebuild for new Python

* Sat Oct 19 2013 umeabot <umeabot> 0.99-0.beta18.6.mga4
+ Revision: 535978
- Mageia 4 Mass Rebuild

* Sat Sep 21 2013 fwang <fwang> 0.99-0.beta18.5.mga4
+ Revision: 482876
- update file list

* Sat Jan 12 2013 umeabot <umeabot> 0.99-0.beta18.5.mga3
+ Revision: 356889
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ boklm <boklm>
- Update group: Graphics/Other -> Graphics/Utilities

* Mon Dec 31 2012 pterjan <pterjan> 0.99-0.beta18.4.mga3
+ Revision: 336467
- Fix build with automake 1.13

* Thu Nov 01 2012 pterjan <pterjan> 0.99-0.beta18.3.mga3
+ Revision: 312299
- Fix build with -Werror=format-security
+ fwang <fwang>
- use autoreconf
- add patch from pld-linux to build with latest ruby
- rebuild for new ruby

* Wed Oct 03 2012 malo <malo> 0.99-0.beta18.2.mga3
+ Revision: 302708
- update RPM group

* Wed Jul 11 2012 pterjan <pterjan> 0.99-0.beta18.1.mga3
+ Revision: 269356
- Package python binding
- Update to beta18

* Mon Jan 23 2012 dmorgan <dmorgan> 0.99-0.beta17.5.mga2
+ Revision: 200162
- Own %%_libdir/caca

* Sun Nov 20 2011 dmorgan <dmorgan> 0.99-0.beta17.4.mga2
+ Revision: 170122
- Remove .la files
  Disable java binding

* Wed Jul 20 2011 fwang <fwang> 0.99-0.beta17.3.mga2
+ Revision: 127443
- updated br

* Sat Jan 15 2011 mikala <mikala> 0.99-0.beta17.2.mga1
+ Revision: 18507
- Drop mdk macros
- Remove BuildRoot
- imported package libcaca


* Mon Nov 29 2010 Funda Wang <fwang@mandriva.org> 0.99-0.beta17.2mdv2011.0
+ Revision: 602958
- reduce BR
- update file list

  + Oden Eriksson <oeriksson@mandriva.com>
    - rebuild

* Mon Feb 08 2010 Pascal Terjan <pterjan@mandriva.org> 0.99-0.beta17.1mdv2010.1
+ Revision: 502259
- Update to beta17

  + Götz Waschk <waschk@mandriva.org>
    - fix devel provides

* Sun Sep 27 2009 Olivier Blin <oblin@mandriva.com> 0.99-0.beta16.5mdv2010.0
+ Revision: 449857
- fix libtool troubles (from Arnaud Patard)
- disable mono on arm too
- disable mono on mips (from Arnaud Patard)

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 0.99-0.beta16.4mdv2010.0
+ Revision: 425523
- rebuild

  + Pascal Terjan <pterjan@mandriva.org>
    - Use plugins to not link the lib against X

* Fri Nov 07 2008 Götz Waschk <waschk@mandriva.org> 0.99-0.beta16.2mdv2009.1
+ Revision: 300541
- rebuild for new libxcb

* Sat Oct 18 2008 Pascal Terjan <pterjan@mandriva.org> 0.99-0.beta16.1mdv2009.1
+ Revision: 294925
- Update to beta16

* Tue Oct 14 2008 Götz Waschk <waschk@mandriva.org> 0.99-0.beta15.3mdv2009.1
+ Revision: 293564
- fix pkgconfig file

* Sat Oct 11 2008 Götz Waschk <waschk@mandriva.org> 0.99-0.beta15.2mdv2009.1
+ Revision: 292189
- rebuild
- new version
- update file list

* Fri Jul 18 2008 Pascal Terjan <pterjan@mandriva.org> 0.99-0.beta14.1mdv2009.0
+ Revision: 238226
- Update to beta 14
- Disable --no-undefined for ruby binding

* Fri Jun 13 2008 Götz Waschk <waschk@mandriva.org> 0.99-0.beta13.2mdv2009.0
+ Revision: 218743
- 0.99beta13b
- new version
- drop ruby patch
- patch for gcc 4.3

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

  + Pascal Terjan <pterjan@mandriva.org>
    - Update URL
    - Fix license

* Thu Nov 29 2007 Pascal Terjan <pterjan@mandriva.org> 0.99-0.beta13.1mdv2008.1
+ Revision: 113868
- update to 0.99 beta13
- build C# and Ruby bindings

* Mon Oct 22 2007 Götz Waschk <waschk@mandriva.org> 0.99-0.beta12.1mdv2008.1
+ Revision: 101111
- new version
- drop patch
- new devel name

  + Thierry Vignaud <tv@mandriva.org>
    - replace %%{_datadir}/man by %%{_mandir}!

* Fri Jun 01 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 0.99-0.beta11.2mdv2008.0
+ Revision: 34314
- Rebuild with libslang2.


* Mon Dec 04 2006 Götz Waschk <waschk@mandriva.org> 0.99-0.beta11.1mdv2007.0
+ Revision: 90333
- Import libcaca

* Mon Dec 04 2006 Götz Waschk <waschk@mandriva.org> 0.99-0.beta11.1mdv2007.1
- fix buildrequires
- rediff patch 1
- add library package
- drop patch 0
- new version

* Tue Sep 19 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.9-15mdv2007.0
- Rebuild

* Thu Jun 15 2006 Götz Waschk <waschk@mandriva.org> 0.9-14mdv2007.0
- disable slang on x86_64 to make it build

* Wed Jun 14 2006 Götz Waschk <waschk@mandriva.org> 0.9-13mdv2007.0
- remove debug files
- fix devel deps

* Tue May 23 2006 Thierry Vignaud <tvignaud@mandriva.com> 0.9-12mdk
- fix requires

* Sat May 20 2006 Thierry Vignaud <tvignaud@mandriva.com> 0.9-11mdk
- fix buildrequires

* Sat Dec 31 2005 Mandriva Linux Team <http://www.mandrivaexpert.com/> 0.9-10mdk
- Rebuild

* Thu Aug 18 2005 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 0.9-9mdk
- Rebuild

* Sun Feb 20 2005 Christiaan Welvaart <cjw@daneel.dyndns.org> 0.9-8mdk
- Patch1: fix a4wide check for new file location

* Mon Jan 31 2005 Götz Waschk <waschk@linux-mandrake.com> 0.9-7mdk
- multiarch support

* Sat Aug 07 2004 Götz Waschk <waschk@linux-mandrake.com> 0.9-6mdk
- really fix buildrequires

* Thu Aug 05 2004 Götz Waschk <waschk@linux-mandrake.com> 0.9-4mdk
- patch to fix man pages build

* Sat May 01 2004 Götz Waschk <waschk@linux-mandrake.com> 0.9-3mdk
- fix 9.0 build

* Sat Feb 07 2004 Götz Waschk <waschk@linux-mandrake.com> 0.9-2mdk
- fix directory ownership

* Mon Feb 02 2004 Götz Waschk <waschk@linux-mandrake.com> 0.9-1mdk
- new version

* Mon Feb 02 2004 Sam Hocevar (RPM packages) <sam+rpm@zoy.org> 0.9-1
- new release

* Sun Jan 18 2004 Sam Hocevar (RPM packages) <sam+rpm@zoy.org> 0.8-1
- new release

* Wed Jan 07 2004 Sam Hocevar (RPM packages) <sam+rpm@zoy.org> 0.7-1
- new release

* Sun Jan 04 2004 Sam Hocevar (RPM packages) <sam+rpm@zoy.org> 0.6-2
- install documentation into {doc}/package-version instead of {doc}/package
- added tetex-dvips to the build dependencies

* Sat Jan 03 2004 Sam Hocevar (RPM packages) <sam+rpm@zoy.org> 0.6-1
- new release
- more detailed descriptions
- split the RPM into libcaca-devel and caca-utils
- packages are rpmlint clean

* Mon Dec 29 2003 Richard Zidlicky <rz@linux-m68k.org> 0.5-1
- created specfile

